Welcome to ClientVPS Mirrors

Help for package airqualityES
Title: Air Quality Measurements in Spain from 2011 to 2018
Version: 1.0.0
Description: These dataset contains daily quality air measurements in Spain over a period of 18 years (from 2001 to 2018). The measurements refer to several pollutants. These data are openly published by the Government of Spain. The datasets were originally spread over a number of files and formats. Here, the same information is contained in simple dataframe for convenience of researches, journalists or general public. See the Spanish Government website http://www.miteco.gob.es/ for more information.
Depends: R (≥ 3.4.0)
License: CC BY-SA 4.0
Encoding: UTF-8
LazyData: true
Imports: tibble (≥ 2.1.3)
Suggests: knitr, rmarkdown
URL: https://github.com/jdieramon/airqualityES
BugReports: https://github.com/jdieramon/airqualityES/issues
RoxygenNote: 6.1.1
NeedsCompilation: no
Packaged: 2020-02-23 08:39:37 UTC; josedie
Author: Jose V. Die ORCID iD [aut, cre], Jose R. Caro [ctb]
Maintainer: Jose V. Die <jose.die@uco.es>
Repository: CRAN
Date/Publication: 2020-02-29 13:30:02 UTC

airqualityES: Air Quality Measurements in Spain

Description

aiqualityES dataset contains daily quality air measurements from 2001 to 2018.

Author(s)

Jose V. Die jose.die@uco.es, Jose R. Caro

See Also

Useful links:


Air quality measurements in Spain

Description

Daily data referred to several pollutants (from 2001 to 2018).

Usage

data(airqES)

Format

A data.frame with 112,484 rows and columns:

Author(s)

Jose V. Die & Jose R. Caro

Official data Government of Spain.


Air stations in Spain

Description

Description of station features.

Usage

data(stations)

Format

A data.frame with 604 rows and columns:

Author(s)

Jose V. Die & Jose R. Caro

Official data Government of Spain.

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.